function [Aj,Vj,rhoj,T0j,pj,Mj,mdot_off,NcL_off,delta_T] = TJab_off(ab,T,V,h,T_0,p_0,M_0,Max_T_dry,beta_cL,beta_cH,TIT,A_0,A_e,mdot_proj,L_conv,L_div,div_angle,T0_e_ab,mdot_ab)

% This function computes thrust and exhaust nozzle parameters (jet speed,
% jet total temperature, jet static pressure, jet density) for a 2-spool
% turbojet with afterburner and variable area nozzle. Efficiencies and
% losses are reffered to Concorde available data.

% INPUT DATA:
% Operating conditions:
% - ab: ab = 1 afterburner ON, ab = 0 afterburner OFF
% Ambient conditions: 
% - T_0: ambient static temperature [K]
% - p_0: ambient static pressure [Pa]
% - M_0: aircraft Mach number
% Engine data
% - beta_cL: Low Compressor Ratio
% - beta_cH: High Compressor Ratio
% - TIT: Turbine Inlet Temperature [K]
% - A_0: Inet area [m^2]
% - mdot_proj: Air mass flow [Kg/s]
% - L_conv: covergent duct length [m]
% - L_div: divergent duct length [m]
% Afterburner data
% - T0_e_ab: Afterburner exit temperature [K]
% - mdot_ab: Afterburner propellant mass flow [kg/s]

% Efficiencies & Losses

    eta_mcL = 1;                                            % Mecanic low compressor efficiency
    eta_mcH = 1;                                            % Mecanic high compressor efficiency
    eta_mtL = 0.95;                                         % Mecanic low turbine efficiency
    eta_mtH = 0.95;                                         % Mecanic  high turbine efficiency
    epsilon_d = 0.98;                                       % Pneumatic inlet efficiency
    epsilon_n = 1;                                          % Pneumatic nozzle efficiency
    epsilon_b = 1;                                          % Pneumatic combustor losses
    eta_n = 1;                                              % Nozzle efficiency
    eta_b = 1;                                              % Combustor efficiency
    eta_cL = 0.895;                                         % Low compressor efficiency
    eta_cH = 0.901;                                         % High compressor efficiency
    eta_tL = 0.88;                                          % Low turbine efficiency
    eta_tH = 0.893;                                         % High turbine efficiency
    eta_ab = 0.99;                                          % Afterburner efficiency
    epsilon_ab = 0.9;                                       % Afterburner losses
    
% Air & fuel
    
    R = 287;                                                % Air gases constant [J/(kg*K)]
    R1 = 293;                                               % Combusted gases constant [J/(kg*K)]
    c_p = 1004;                                             % Air specific heat [J/(kg*K)]
    c_p1 = 1184;                                            % Combusted gases specific heat [J/(kg*K)]
    gamma = 1.375;                                          % Air adiabatic expansion coefficient
    gamma1 = 1.3;                                           % Combusted gases adiabatic expansion coefficient
    H_i = 43260000;                                         % Heats of reaction [J/kg]
 
% OFF DESIGN: Variation of M_0 and altitude

% If the thrust is lower that the lowest thrust level
if T < 10000*0.4482
    T = 10000*0.4482;
end

% rho_0 = p_0/(R*T_0);
% a = sqrt(gamma*R*T_0);


% If the afterburner is ON, the engine parameters are assumed to be equal to
% the ones when the maximum thrust dry occurs.

TIT_off = 0.5*TIT+(TIT-0.5*TIT)*((T-(0.05*Max_T_dry))/(Max_T_dry-(0.05*Max_T_dry)));
tau =  TIT_off/TIT;
if tau > 1
    tau = 1;
end

tau_axes = [0.5 0.6 0.7 0.8 0.9 1];
beta_cL_off = [1.53 1.95 2.22 2.51 2.85 3.23];
beta_cH_off = [2.75 3.05 3.44 3.85 4.32 4.78];
NcL_off = [0.6 0.7 0.76 0.82 0.9 1];
mdot_off = [71 93 110 130 157 186];

ind = find(tau == tau_axes);
    if isempty(ind)
        i1 = find(tau > tau_axes,1,'last');
        i2 = find(tau < tau_axes,1,'first');
        beta_cL_off = beta_cL_off(i1) + (beta_cL_off(i2) - beta_cL_off(i1))*(tau - tau_axes(i1))/(tau_axes(i2) - tau_axes(i1));
        beta_cH_off = beta_cH_off(i1) + (beta_cH_off(i2) - beta_cH_off(i1))*(tau - tau_axes(i1))/(tau_axes(i2) - tau_axes(i1));
        NcL_off = NcL_off(i1) + (NcL_off(i2) - NcL_off(i1))*(tau - tau_axes(i1))/(tau_axes(i2) - tau_axes(i1));
        mdot_off =  mdot_off(i1) + (mdot_off(i2) - mdot_off(i1))*(tau - tau_axes(i1))/(tau_axes(i2) - tau_axes(i1));
    else
        beta_cL_off = beta_cL_off(ind);
        beta_cH_off = beta_cH_off(ind);
        NcL_off = NcL_off(ind);
        mdot_off =  mdot_off(ind);
    end    

if T > 10000*4.4482
T_axes = [10000 20000 28000 32000 39653]*4.4482;
NPR = [1.9 2.15 2.42 2.55 3];
    ind = find(T == T_axes);
    if isempty(ind)
        i1 = find(T > T_axes,1,'last');
        i2 = find(T < T_axes,1,'first');
        NPR_off = (NPR(i1) + (NPR(i2) - NPR(i1))*(T - T_axes(i1))/(T_axes(i2) - T_axes(i1)));
    else
        NPR_off = NPR(ind);
    end
else
    NPR_off = 1;
end
   
    % ENGINE CORE:
    
    % Inlet values
    T0_0 = T_0 * (1+(gamma - 1)/2 * M_0^(2)); 
    p0_0 = p_0 * (1+(gamma - 1)/2 * M_0^(2))^(gamma/(gamma - 1));

    % Inlet mass flow rate
    % mdot_off = p0_0 * A_0/(R * T0_0) * (sqrt(gamma) * (M_0/(1 + ((gamma - 1)/2)) * M_0^2)^((gamma + 1)/(2 * (gamma - 1)))); 
    % mdot_proj = 186;        

    %mdot_off = mdot_off*((rho_0)/1.225);

    %%% PROCESSING %%%

    % Values after inlet
    T0_1 = T0_0;
    p0_1 = epsilon_d * p0_0;

    % Values after first compression
    T0_21 = T0_1 * (1 + 1/eta_cL * (beta_cL_off^((gamma - 1)/gamma) - 1));
    p0_21 = beta_cL_off * p0_1;
    delta_T = (T0_21-T0_1);
    
    % Values after second compression
    T0_2 = T0_21 * (1 + 1/eta_cH * (beta_cH_off^((gamma - 1)/gamma) - 1));
    p0_2 = beta_cH_off * p0_21;

    % Values after combustion
    p0_3 = epsilon_b * p0_2;
    T0_3 = TIT_off;
    
    % Fuel ratio
    f = c_p1 * (T0_3 - T0_2)/((eta_b * H_i) - c_p1 * (T0_3 - T0_2)); 
    % Air ratio
    %alpha = 1/f; 
    mdot_off_ab = mdot_off*(1 + f) + mdot_ab;
    
    %Variation of M_0 makes change air flow mass
    %M_proj = 0.7;
    %p0_0_proj = p_0 * (1+(gamma - 1)/2 * M_proj^(2))^(gamma/(gamma - 1));


    % Expansion High-Pressure Turbine Ratio
    beta_tH = (1 - c_p * (T0_2 - T0_21) / (c_p1 * eta_mcH * eta_mtH * eta_tH * (1 + f) * T0_3))^(-gamma1/(gamma1 - 1));

    % Values after first expansion in turbine
    T0_41 = T0_3 - c_p/c_p1 * (1 / (eta_mtH * eta_mcH)) * ((T0_2 - T0_21)/(1 + f)); 
    p0_41 = p0_3 / beta_tH;

    
    % Expansion Low-Pressure Turbine Ratio
    beta_tL = (1 - c_p * (T0_21 - T0_1) / (c_p1 * eta_mcL * eta_mtL * eta_tL * (1 + f) * T0_41))^(-gamma1/(gamma1 - 1));

    % Values after second expansion in turbine
    T0_4 = T0_41 - c_p/c_p1 * (1 / (eta_mtL * eta_mcL)) * ((T0_21 - T0_1)/(1 + f)); 
    p0_4 = p0_41 / beta_tL;
   
    
    % EXHAUST SYSTEM:
    
    %--Convergent duct
    
    % Exit values 
    T0_e = T0_4;
    p0_e = epsilon_n * p0_4;
    
    % Values with afterburner 
    p0_e_ab = epsilon_ab * p0_4;
    
    %--Throat: Hyp: Mt = 1
    
    p_t = p0_e / ((gamma1 + 1)/2)^(gamma1 / (gamma1 - 1));
    T_t = T0_e / ((gamma1 + 1)/2);
    rho_t = p_t / (R1 * T_t);
    
    %w_t = sqrt(gamma1 * R1 * T_t);

    % EXHAUST JET PARAMETERS:
    % Hyp:
    % - The nozzle is a typical divergent ejector nozzle with fixed NPR for
    %   each thrust level.
    
if ab == 0 %Afterburner OFF
    
   if T > 10000*4.4482
       pj = p0_e/(NPR_off);
       Aj = 1.2*A_e; % Exhaust system exit area
       
       Mj = sqrt((((p0_e/pj)^((gamma1-1)/gamma1))-1)*(2/(gamma1-1)));
       Vj = (1/(1+f))*(V+(((T - Aj*(pj-p_0)))/mdot_off));

      T0j = T0_e;
    
      aj = Vj/Mj;
      Tj = aj^2/(gamma1*R1);
      rhoj = pj/(R1*Tj);
   else % Lowest thrust -->  adapeted nozzle, no supersonic jet
      pj = p_0;
      Aj = A_e; % Exhaust system exit area
       
      Mj = 1;
      Vj = (1/(1+f))*(V+(((T - Aj*(pj-p_0)))/mdot_off));

      T0j = T0_e;
    
      aj = Vj/Mj;
      Tj = aj^2/(gamma1*R1);
      rhoj = pj/(R1*Tj);
    end
   
    elseif ab == 1 %Afterburner ON
        
        pj = p0_e_ab/(NPR_off);
        T0j = T0_e_ab;
        
        % Conv. section -> crictic conditions
        p_t = p0_e_ab / ((gamma1 + 1)/2)^(gamma1 / (gamma1 - 1));
        T_t = T0_e_ab / ((gamma1 + 1)/2);
        rho_t = p_t / (R1 * T_t);
        a_t = sqrt(gamma1*R1*T_t); 
        A_t_ab = mdot_off_ab/(rho_t*a_t); %New throat area to avoid chocking
        
        % Div. section
        Aj = 1.2*A_t_ab;
        Mj = sqrt((((NPR_off)^((gamma1-1)/gamma1))-1)*(2/(gamma1-1)));
        Vj = (1/(1+f))*(V+(((T - Aj*(pj-p_0)))/mdot_off_ab));
        aj = Vj/Mj;
        Tj = aj^2/(gamma1*R1);
        rhoj = pj/(R1*Tj);
        %Mj = Vj/aj;
end
end

