function [PNL,PNLT,C_tone] = compute_PNL(SPL)

%This function computes EPNL from SPL following the procedure specified in
%ICAO, Annex 16, Volume I, Appendix 2. It gives in output Effective
%Perceived Noise Level estimate throught aproximate calculation, PNL, PNLT
%and PNLM.

%*************************************************************************%
%******************* c. Perceived noise level (PNL) **********************%
%************ the conversion from SPL to PNL is specified in ICAO ********%
%******************** Annex 16, Volume I, Appendix 2 *********************%
%******************************  p.154  **********************************%
%*************************************************************************%

% - Convert each measured one-third octave band sound pressure level
%   from 50 to 10,000 Hz, SPL(i,k), that occurs at any given instant
%   of time to received noisiness, n(i,k), by reference to Tab of noy
%   levels.

f = [50 63 80 100 125 160 200 250 315 400 500 630 800 1000 1250 1600 2000 2500 3150 4000 5000 6300 8000 10000]; %frequenze centrali tra 50 e 10000 Hz in 1/3 di ottava

SPL_a = [91 85.9 87.3 79.0 79.8 76.0 74.0 74.9 94.6 Inf Inf Inf Inf Inf Inf Inf Inf Inf Inf Inf Inf Inf 44.3 50.7];
SPL_b = [64 60 56 53 51 48 46 44 42 40 40 40 40 40 38 34 32 30 29 29 30 31 37 41];
SPL_c = [52 51 49 47 46 45 43 42 41 40 40 40 40 40 38 34 32 30 29 29 30 31 34 37];
SPL_d = [49 44 39 34 30 27 24 21 18 16 16 16 16 16 15 12 9 5 4 5 6 10 17 21];
SPL_e = [55 51 46 42 39 36 33 30 27 25 25 25 25 25 23 21 18 15 14 14 15 17 23 29];

M_b = [0.043478 0.040570 0.036831 0.036831 0.035336 0.033333 0.033333 0.032051 0.030675 0.030103 0.030103 0.030103 0.030103 0.030103 0.030103 0.029960 0.029960 0.029960 0.029960 0.029960 0.029960 0.029960 0.042285 0.042285];
M_c = [0.030103 0.030103 0.030103 0.030103 0.030103 0.030103 0.030103 0.030103 0.030103 0 0 0 0 0 0 0 0 0 0 0 0 0.029960 0.029960 0.029960];
M_d = [0.079520 0.068160 0.068160 0.059640 0.053013 0.053013 0.053013 0.053013 0.053013 0.053013 0.053013 0.053013 0.053013 0.053013 0.059640 0.053013 0.053013 0.047712 0.047712 0.053013 0.053013 0.068160 0.079520 0.059640];
M_e = [0.058098 0.058098 0.052288 0.047534 0.043573 0.043573 0.040221 0.037349 0.034859 0.034859 0.034859 0.034859 0.034859 0.034859 0.034859 0.040221 0.037349 0.034859 0.034859 0.034859 0.034859 0.037349 0.037349 0.043573];

n = zeros(1,length(f));

for i = 1:1:24
    
    if (SPL(i)>= SPL_a(i))
        n(i) = 10^(M_c(i)*(SPL(i)-SPL_c(i)));
    end
    
    if (SPL(i) >=SPL_b(i)) && (SPL(i)<SPL_a(i))
        n(i) = 10^(M_b(i)*(SPL(i)-SPL_b(i)));
    end
    
    if (SPL(i)>= SPL_e(i)) && (SPL(i)<SPL_b(i))
        n(i) = 0.3*10^(M_e(i)*(SPL(i)-SPL_e(i)));
    end
    
   if (SPL(i)>= SPL_d(i)) && (SPL(i)<SPL_e(i))
        n(i) = 0.1*10^(M_d(i)*(SPL(i)-SPL_d(i)));
   end
end

% - The noy values, n(i) found in Step 1 are combined in the manner
%   prescribed by the following formula: N(k) = 0.85*n_max(k) +0.15*(sum(n(k,i)))

n_max = max(n);
N = 0.85*n_max +0.15*(sum(n)); %Total perceived noisiness

% - The total perceived noisiness, N, is converted into perceived noise
%   level, PNL, by means of the following formula: 
%   PNL(k)= 40 + (10/log(2))*log(N)
if N<1
    N = 1;
end
PNL = 40 + (10/log10(2))*log10(N); %Perceived Noise Level at k-th time instant

%*************************************************************************%
%************************* d. Tone correction ****************************%
%**** the calculation of tone correction factor is specified in ICAO *****%
%******************** Annex 16, Volume I, Appendix 2 *********************%
%******************************  p.154  **********************************%
%*************************************************************************%

% 1st correction

diff = zeros(1, length(f)); % diff = SPL(i) - SPL(i-1)
diff_diff = zeros(1, length(f)); % diff_diff = diff(i) - diff(i-1)
SPL_I = zeros(1, length(f)); %new SPL corrected

for i = 4:1:24
    
    diff(i) = (SPL(i)-SPL(i-1));

end

for i = 2:1:24
    
    diff_diff(i) = abs(diff(i) - diff(i-1));
    
    if (diff_diff(i)>5) && (diff(i)>0) && (diff(i)>diff(i-1))
        encircle = SPL(i);
    elseif(diff_diff(i)>5) && (diff(i)<=0) && (diff(i-1)>0)
        encircle = SPL(i-1);
    end
    
    if exist('encircle') && (i<23)
        SPL_I(i) = (SPL(i-1)+SPL(i+1))/2;
    elseif exist('encircle') && (i==24)
        SPL_I(i) = (SPL(i-1)+diff(i-1));
    else
        SPL_I(i) = SPL(i);
    end
    
end


%2nd correction

diff_I = zeros(1, length(f)+1); % diff_I = SPL_I(i) - SPL_I(i-1)
average_II = zeros(1, length(f)); % average of three adiacent slope (diff_I)
SPL_II = zeros(1, length(f)); %new SPL_I corrected

for i = 4:1:24
    
    diff_I(i) = (SPL_I(i)-SPL_I(i-1));
    
end
   diff_I(3) = diff(4);
   diff_I(25) = diff(24);
   

for i = 3:1:24
    
    if  (i<23)
        average_II(i) = (diff_I(i)+diff_I(i+1)+diff_I(i+2))/3;
    end
    
SPL_II(i) = SPL_I(i-1)+average_II(i-1);
end

SPL_II(1) = SPL(1);
SPL_II(2) = SPL(2);

%Final difference

Final_difference = zeros(1,length(f));
tone = zeros(1,length(f));

for i = 1:24
    
Final_difference(i) = SPL(i)-SPL_II(i);

end

for i = 1:11 % 50 Hz <= f <= 500 Hz
    if (Final_difference(i)>= 1.5) && (Final_difference(i)< 3)
        tone(i) = Final_difference(i)/3;
    elseif (Final_difference(i)>= 3) && (Final_difference(i)< 20)
        tone(i) = Final_difference(i)/6;
    elseif (Final_difference(i) > 20)
        tone(i) = 3.33;
%     else
%         tone(i) = Final_difference(i);
    end
end

for i = 12:22 % 500 Hz <= f <= 5000 Hz
    if (Final_difference(i)>= 1.5) && (Final_difference(i)< 3)
        tone(i) = 2*Final_difference(i)/3;
    elseif (Final_difference(i)>= 3) && (Final_difference(i)< 20)
        tone(i) = Final_difference(i)/6;
    elseif (Final_difference(i) > 20)
        tone(i) = 6.66;
%     else
%         tone(i) = Final_difference(i);
    end
end

for i = 23:24 % 5000 Hz <= f <= 10000 Hz
    if (Final_difference(i)>= 1.5) && (Final_difference(i)< 3)
        tone(i) = Final_difference(i)/3;
    elseif (Final_difference(i)>= 3) && (Final_difference(i)< 20)
        tone(i) = Final_difference(i)/6;
    elseif (Final_difference(i) > 20)
        tone(i) = 3.33;
%     else
%         tone(i) = Final_difference(i);
    end
end
C_tone = max(tone);

     
%*************************************************************************%
%******************************* e. PNLT *********************************%
%**** the calculation of tone correction factor is specified in ICAO *****%
%******************** Annex 16, Volume I, Appendix 2 *********************%
%******************************  p.154  **********************************%
%*************************************************************************%

PNLT = PNL+C_tone; %Tone corrected perceived noise level at k-th istant of time

end




